@@ -7,7 +7,7 @@ NULL
 #' @aliases get_data,MultivariateAnalysis-method
 setMethod(
   f = "get_data",
-  signature = signature(x = "MultivariateAnalysis"),
+  signature = c(x = "MultivariateAnalysis"),
   definition = function(x) {
     as.data.frame(x@data)
   }
